iterationtools.iterate_semantic_voices_in_expr
==============================================

.. autofunction:: abjad.tools.iterationtools.iterate_semantic_voices_in_expr.iterate_semantic_voices_in_expr
   :noindex:
